do "$root/Analyses/aux/set_globals"
use "$root/Data/survey_analysis_final.dta", clear

graph drop _all

***********************************************************************************
* Figure 9 (Left Panel): Counterfactual policy clusters
***********************************************************************************

drop if inlist(country, "Korea", "Brazil")

* Margins command cannot generate new variables, so use the adjust command.
* Adjust command does not work with fixed effects (the i. notation), so need to
* manually generate fixed effects
foreach country in $countries_western {
	qui gen `country'=0
	qui replace `country'=1 if country=="`country'"
}

foreach j in $policies{
	
	qui reg s_`j'_portion universalism_overall Australia Germany France Sweden $controls, ro
	
	* Prediction made including heterogeneity in universalism
	predict predct_`j'_hetero
	
	* Prediction collapsing all variation in individual variables (counterfactuals)
	
	* Universalism
	adjust universalism_overall, se generate(predct_`j'_homo_univ)
	
	* Demographics, one at a time
	adjust age, generate(predct_`j'_homo_age)
	adjust male, generate(predct_`j'_homo_male)
	adjust s_religion_index, generate(predct_`j'_homo_rel)
	adjust s_wealth_index, generate(predct_`j'_homo_wealth)
	adjust s_income_index, generate(predct_`j'_homo_income)
	adjust college, generate(predct_`j'_homo_coll)
	adjust neighborhood_size_0to9, generate(predct_`j'_homo_urban)
	adjust inefficiency_equity, generate(predct_`j'_homo_ineff)
	adjust altruism, generate(predct_`j'_homo_altr)
	adjust gen_trust, generate(predct_`j'_homo_trust)
	adjust govt_wasteful0_efficient_10, generate(predct_`j'_homo_govt)
	
}

foreach i in hetero homo_univ homo_age homo_male homo_rel homo_wealth homo_income ///
homo_coll homo_urban homo_ineff homo_altr homo_trust homo_govt {
	foreach j in $policies {
		egen s_predct_`j'_`i'=std(predct_`j'_`i')
	}
}

* Intracorrelations with full heterogeneity

label var s_predct_border_hetero "Border"
label var s_predct_military_hetero "Military"
label var s_predct_police_hetero "Police"
label var s_predct_foreignaid_hetero "Foreign Aid"
label var s_predct_affaction_hetero "Affirmative Action"
label var s_predct_environment_hetero "Environment"
label var s_predct_health_hetero "Healthcare"
label var s_predct_welfare_hetero "Welfare"

foreach i in age male rel wealth income coll urban ineff altr trust govt univ {
	label var s_predct_border_homo_`i' "Border"
	label var s_predct_military_homo_`i' "Military"
	label var s_predct_police_homo_`i' "Police"
	label var s_predct_foreignaid_homo_`i' "Foreign Aid"
	label var s_predct_affaction_homo_`i' "Affirmative Action"
	label var s_predct_environment_homo_`i' "Environment"
	label var s_predct_health_homo_`i' "Healthcare"
	label var s_predct_welfare_homo_`i' "Welfare"
}

drop predct_*
rename s_predct_* predct_*

* Rename due to variable name length limits
rename predct_foreignaid_* predct_fornaid_*
rename predct_environment_* predct_enment_*
rename predct_affaction_* predct_aff_*

global policies "border military police fornaid aff enment health welfare"

foreach i in hetero homo_age homo_male homo_rel homo_wealth homo_income ///
homo_coll homo_urban homo_ineff homo_altr homo_trust homo_govt homo_univ {
	
	* Correlations between predictions of policy view, including country FE

	foreach k in $policies {
		
		foreach m in $policies {
			
			gen b_`k'_`m'_`i'=.
			
			qui reg predct_`k'_`i' predct_`m'_`i' i.country_no
			
			replace b_`k'_`m'_`i'=_b[predct_`m'_`i']
		}
	}	
}
	
keep b_*
gen id=1
keep if _n==1

reshape long b_, i(id) j(policies, string)

split policies, parse(_) generate(temp)
drop policies
rename temp1 policy_i
rename temp2 policy_j
gen model=temp3+"_"+temp4
replace model=temp3 if temp3=="hetero"

drop temp* id

rename *_ *

* Recoding: want to understand the magnitude of correlations that "go in the hypothesized
* direction", i.e. positive if between two left-framed policies or two right-framed
* policies, and negative if between a left-framed and a right-framed policy. So
* those correlations that go in the "right" direction we treat as positive, and
* those that don't as negative.
foreach i in fornaid aff enment health welfare {
	foreach j in border military police {
		replace b=(-1)*b if (policy_i=="`i'" | policy_j=="`i'") & (policy_i=="`j'" | policy_j=="`j'") & policy_i!=policy_j
		
	}
}

* Drop correlations of predictions with themselves
drop if policy_i==policy_j

* Also keep just one of the correlations for every pair (i.e., right now have
* both correlation between healthcare and military, and military and healthcare)
gen policy_comb=policy_i+" "+policy_j if policy_i < policy_j
replace policy_comb=policy_j+" "+policy_i if policy_comb==""
bysort model policy_comb (policy_i): keep if _n==1

collapse (mean) b, by(model)

gen order=1
replace order=2 if model=="homo_age"
replace order=3 if model=="homo_male"
replace order=4 if model=="homo_rel"
replace order=5 if model=="homo_income"
replace order=6 if model=="homo_wealth"
replace order=7 if model=="homo_coll"
replace order=8 if model=="homo_urban"
replace order=9 if model=="homo_altr"
replace order=10 if model=="homo_trust"
replace order=11 if model=="homo_ineff"
replace order=12 if model=="homo_govt"
replace order=13 if model=="homo_univ"

tw (bar b order, fcolor(blue%50) lcolor(blue%50)), ///
	xlabel(1 "Full Heterogeneity" 2 "Age" 3 "Gender" 4 "Religiosity" ///
	5 "Income" 6 "Wealth" 7 "College" 8 "Urbanicity" 9 "Altruism" 10 "Trust" 11 "Efficiency vs. Equity" 12 "Gov't Efficient" 13 "Universalism", labsize(small) angle(40)) ///
	ylabel(0.3(0.1)0.8, labsize(small)) yscale(r(0.3 0.8) noline) ///
	xtitle("Predictor") graphregion(color(white)) ///
	ytitle("Average correlation", size(small) height(6)) ///
	title("Average correlation between predicted policy views", size(medsmall)) ///
	subtitle("Collapsing variation in...", size(small))

graph export "$root/Output/fig_9a_hypo_clusters.eps", replace
	
	